@@ -30,7 +30,7 @@ class to handle authentication and token manipulation.
 import json
 from typing import Optional
 
-from jose import jwt
+from jwcrypto import jwk, jwt
 
 from .authorization import Authorization
 from .connection import ConnectionManager
@@ -477,7 +477,7 @@ class KeycloakOpenID:
         params_path = {"realm-name": self.realm_name, "resource-server-id": resource_server_id}
         data_raw = self.connection.raw_get(URL_ENTITLEMENT.format(**params_path))
 
-        if data_raw.status_code == 404:
+        if data_raw.status_code == 404 or data_raw.status_code == 405:
             return raise_error_from_response(data_raw, KeycloakDeprecationError)
 
         return raise_error_from_response(data_raw, KeycloakGetError)  # pragma: no cover
@@ -539,7 +539,16 @@ class KeycloakOpenID:
         :returns: Decoded token
         :rtype: dict
         """
-        return jwt.decode(token, key, algorithms=algorithms, audience=self.client_id, **kwargs)
+        # To keep the same API, we map the python-jose options to our claims for jwcrypto
+        # Per the jwcrypto dev, `exp` and `nbf` are always checked
+        options = kwargs.get("options", {})
+        check_claims = {}
+        if options.get("verify_aud") is True:
+            check_claims["aud"] = self.client_id
+
+        k = jwk.JWK.from_pem(key.encode("utf-8"))
+        full_jwt = jwt.JWT(jwt=token, key=k, algs=algorithms, check_claims=check_claims)
+        return jwt.json_decode(full_jwt.claims)
 
     def load_authorization_config(self, path):
         """Load Keycloak settings (authorization).
@@ -700,7 +709,7 @@ class KeycloakOpenID:
         """Create a client.
 
         ClientRepresentation:
-        https://www.keycloak.org/docs-api/18.0/rest-api/index.html#_clientrepresentation
+        https://www.keycloak.org/docs-api/24.0.2/rest-api/index.html#_clientrepresentation
 
         :param token: Initial access token
         :type token: str
@@ -736,9 +745,7 @@ class KeycloakOpenID:
         :rtype: dict
         """
         params_path = {"realm-name": self.realm_name}
-        payload = {
-            "client_id": self.client_id,
-        }
+        payload = {"client_id": self.client_id}
 
         payload = self._add_secret_key(payload)
         data_raw = self.connection.raw_post(URL_DEVICE.format(**params_path), data=payload)
@@ -748,7 +755,7 @@ class KeycloakOpenID:
         """Update a client.
 
         ClientRepresentation:
-        https://www.keycloak.org/docs-api/18.0/rest-api/index.html#_clientrepresentation
+        https://www.keycloak.org/docs-api/24.0.2/rest-api/index.html#_clientrepresentation
 
         :param token: registration access token
         :type token: str
